==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeAPIServerStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class KubeAPIServerStatusBuilder extends io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatus,io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusBuilder>{
  public KubeAPIServerStatusBuilder() {
    this(false);
  }
  public KubeAPIServerStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new KubeAPIServerStatus(), validationEnabled);
  }
  public KubeAPIServerStatusBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public KubeAPIServerStatusBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new KubeAPIServerStatus(), validationEnabled);
  }
  public KubeAPIServerStatusBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatus instance) {
    this(fluent, instance, false);
  }
  public KubeAPIServerStatusBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGenerations(instance.getGenerations()); 
    fluent.withLatestAvailableRevision(instance.getLatestAvailableRevision()); 
    fluent.withLatestAvailableRevisionReason(instance.getLatestAvailableRevisionReason()); 
    fluent.withNodeStatuses(instance.getNodeStatuses()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  public KubeAPIServerStatusBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatus instance) {
    this(instance,false);
  }
  public KubeAPIServerStatusBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withGenerations(instance.getGenerations()); 
    this.withLatestAvailableRevision(instance.getLatestAvailableRevision()); 
    this.withLatestAvailableRevisionReason(instance.getLatestAvailableRevisionReason()); 
    this.withNodeStatuses(instance.getNodeStatuses()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatus build() {
    KubeAPIServerStatus buildable = new KubeAPIServerStatus(fluent.getConditions(),fluent.getGenerations(),fluent.getLatestAvailableRevision(),fluent.getLatestAvailableRevisionReason(),fluent.getNodeStatuses(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getVersion());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KubeAPIServerStatusBuilder that = (KubeAPIServerStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.4-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeAPIServerStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class KubeAPIServerStatusBuilder extends io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatus,io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusBuilder>{
  public KubeAPIServerStatusBuilder() {
    this(false);
  }
  public KubeAPIServerStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new KubeAPIServerStatus(), validationEnabled);
  }
  public KubeAPIServerStatusBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public KubeAPIServerStatusBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new KubeAPIServerStatus(), validationEnabled);
  }
  public KubeAPIServerStatusBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatus instance) {
    this(fluent, instance, false);
  }
  public KubeAPIServerStatusBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGenerations(instance.getGenerations()); 
    fluent.withLatestAvailableRevision(instance.getLatestAvailableRevision()); 
    fluent.withLatestAvailableRevisionReason(instance.getLatestAvailableRevisionReason()); 
    fluent.withNodeStatuses(instance.getNodeStatuses()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public KubeAPIServerStatusBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatus instance) {
    this(instance,false);
  }
  public KubeAPIServerStatusBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withGenerations(instance.getGenerations()); 
    this.withLatestAvailableRevision(instance.getLatestAvailableRevision()); 
    this.withLatestAvailableRevisionReason(instance.getLatestAvailableRevisionReason()); 
    this.withNodeStatuses(instance.getNodeStatuses()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.KubeAPIServerStatus build() {
    KubeAPIServerStatus buildable = new KubeAPIServerStatus(fluent.getConditions(),fluent.getGenerations(),fluent.getLatestAvailableRevision(),fluent.getLatestAvailableRevisionReason(),fluent.getNodeStatuses(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KubeAPIServerStatusBuilder that = (KubeAPIServerStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
